@@ -3,11 +3,23 @@ archinfo is a collection of classes that contain architecture-specific informati
 It is useful for cross-architecture tools (such as pyvex).
 """
 
-__version__ = (8, 20, 1, 7)
+__version__ = (8, 20, 7, 6)
 
 if bytes is str:
     raise Exception("This module is designed for python 3 only. Please install an older version to use python 2.")
 
+# NewType Declaration, see https://docs.python.org/3/library/typing.html#newtype
+from typing import NewType
+RegisterOffset = NewType('RegisterOffset', int)
+TmpVar = NewType('TmpVar', int)
+
+# This causes too much issues as a NewType, sot is a simple alias instead
+# This means that is still legal to pass any str where a RegisterName is expected.
+# The downside is that PyCharm will show the type as `str` when displaying the signature
+RegisterName = str
+
+
+
 # pylint: disable=wildcard-import
 from .arch import *
 from .defines import defines
