@@ -237,71 +237,83 @@ class ArchAMD64(Arch):
         Register(name='cr8', size=8),
         Register(name='ymm0', size=32, subregisters=[('xmm0', 0, 16),
                                                      ('xmm0lq', 0, 8),
-                                                     ('xmm0hq', 8, 8)],
+                                                     ('xmm0hq', 8, 8),
+                                                     ('ymm0hx', 16, 16)],
                  vector=True),
         Register(name='ymm1', size=32, subregisters=[('xmm1', 0, 16),
                                                      ('xmm1lq', 0, 8),
-                                                     ('xmm1hq', 8, 8)],
+                                                     ('xmm1hq', 8, 8),
+                                                     ('ymm1hx', 16, 16)],
                  vector=True),
         Register(name='ymm2', size=32, subregisters=[('xmm2', 0, 16),
                                                      ('xmm2lq', 0, 8),
-                                                     ('xmm2hq', 8, 8)],
+                                                     ('xmm2hq', 8, 8),
+                                                     ('ymm2hx', 16, 16)],
                  vector=True),
         Register(name='ymm3', size=32, subregisters=[('xmm3', 0, 16),
                                                      ('xmm3lq', 0, 8),
-                                                     ('xmm3hq', 8, 8)],
+                                                     ('xmm3hq', 8, 8),
+                                                     ('ymm3hx', 16, 16)],
                  vector=True),
         Register(name='ymm4', size=32, subregisters=[('xmm4', 0, 16),
                                                      ('xmm4lq', 0, 8),
-                                                     ('xmm4hq', 8, 8)],
+                                                     ('xmm4hq', 8, 8),
+                                                     ('ymm4hx', 16, 16)],
                  vector=True),
         Register(name='ymm5', size=32, subregisters=[('xmm5', 0, 16),
                                                      ('xmm5lq', 0, 8),
-                                                     ('xmm5hq', 8, 8)],
+                                                     ('xmm5hq', 8, 8),
+                                                     ('ymm5hx', 16, 16)],
                  vector=True),
         Register(name='ymm6', size=32, subregisters=[('xmm6', 0, 16),
                                                      ('xmm6lq', 0, 8),
-                                                     ('xmm6hq', 8, 8)],
+                                                     ('xmm6hq', 8, 8),
+                                                     ('ymm6hx', 16, 16)],
                  vector=True),
         Register(name='ymm7', size=32, subregisters=[('xmm7', 0, 16),
                                                      ('xmm7lq', 0, 8),
-                                                     ('xmm7hq', 8, 8)],
+                                                     ('xmm7hq', 8, 8),
+                                                     ('ymm7hx', 16, 16)],
                  vector=True),
         Register(name='ymm8', size=32, subregisters=[('xmm8', 0, 16),
                                                      ('xmm8lq', 0, 8),
-                                                     ('xmm8hq', 8, 8)],
+                                                     ('xmm8hq', 8, 8),
+                                                     ('ymm8hx', 16, 16)],
                  vector=True),
         Register(name='ymm9', size=32, subregisters=[('xmm9', 0, 16),
                                                      ('xmm9lq', 0, 8),
-                                                     ('xmm9hq', 8, 8)],
+                                                     ('xmm9hq', 8, 8),
+                                                     ('ymm9hx', 16, 16)],
                  vector=True),
         Register(name='ymm10', size=32, subregisters=[('xmm10', 0, 16),
                                                       ('xmm10lq', 0, 8),
-                                                      ('xmm10hq', 8, 8)],
+                                                      ('xmm10hq', 8, 8),
+                                                      ('ymm10hx', 16, 16)],
                  vector=True),
         Register(name='ymm11', size=32, subregisters=[('xmm11', 0, 16),
                                                       ('xmm11lq', 0, 8),
-                                                      ('xmm11hq', 8, 8)],
+                                                      ('xmm11hq', 8, 8),
+                                                      ('ymm11hx', 16, 16)],
                  vector=True),
         Register(name='ymm12', size=32, subregisters=[('xmm12', 0, 16),
                                                       ('xmm12lq', 0, 8),
-                                                      ('xmm12hq', 8, 8)],
+                                                      ('xmm12hq', 8, 8),
+                                                      ('ymm12hx', 16, 16)],
                  vector=True),
         Register(name='ymm13', size=32, subregisters=[('xmm13', 0, 16),
                                                       ('xmm13lq', 0, 8),
-                                                      ('xmm13hq', 8, 8)],
+                                                      ('xmm13hq', 8, 8),
+                                                      ('ymm13hx', 16, 16)],
                  vector=True),
         Register(name='ymm14', size=32, subregisters=[('xmm14', 0, 16),
                                                       ('xmm14lq', 0, 8),
-                                                      ('xmm14hq', 8, 8)],
+                                                      ('xmm14hq', 8, 8),
+                                                      ('ymm14hx', 16, 16)],
                  vector=True),
         Register(name='ymm15', size=32, subregisters=[('xmm15', 0, 16),
                                                       ('xmm15lq', 0, 8),
-                                                      ('xmm15hq', 8, 8)],
-                 vector=True),
-        Register(name='ymm16', size=32, subregisters=[('xmm16', 0, 16),
-                                                      ('xmm16lq', 0, 8),
-                                                      ('xmm16hq', 8, 8)],
+                                                      ('xmm15hq', 8, 8),
+                                                      ('ymm15hx', 16, 16)],
                  vector=True),
         Register(name='ftop', size=4, floating_point=True, default_value=(0, False, None)),
         Register(name='fpreg', size=64, subregisters=[('mm0', 0, 8),
